Documentation
¶
Overview ¶
Package trust implements App 3: Trust — audit ledger, compliance, evidence packs, replay lab.
Index ¶
- type App
- func (a *App) Auditor() func(eventType, actor, resource, action string, detail any)
- func (a *App) Description() string
- func (a *App) Migrate(conn *sql.DB) error
- func (a *App) Name() string
- func (a *App) RecordEvent(eventType, actor, resource, action string, detail any) (int64, string)
- func (a *App) RegisterRoutes(mux *http.ServeMux)
- func (a *App) SetBroadcaster(b any)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type App ¶
type App struct {
// contains filtered or unexported fields
}
func (*App) Auditor ¶
Auditor returns a TrustAuditor that other packages can use to record events. This ensures all writes go through the serialized hash chain.
func (*App) Description ¶
func (*App) RecordEvent ¶
RecordEvent appends an entry to the hash-chain audit ledger. Thread-safe — serializes hash chain computation.
func (*App) RegisterRoutes ¶
func (*App) SetBroadcaster ¶
SetBroadcaster subscribes to live proxy events and records them in the audit ledger. Accepts any type that has AddListener(func([]byte)) func() — uses any to work with Go's interface type assertion in engine.go.
Click to show internal directories.
Click to hide internal directories.